<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright EB Dynamics, Inc., Edward Lemmers, P.E.
// For licensing, see license.txt.
// Revised: 2/8/2012	ELL
// Added table prefix handling.
//
	include ("check_session.php");
		
	$ID = $_GET['ID'];
	
	// Now go ahead and delete page record from table.
	$query = "DELETE FROM " . BWB_TABLE_PREFIX . "page_data_bkup WHERE ID = '$ID'";
	$cnt = $bwb_dbh->exec($query);
	
	header("Location: restore_page_select.php");
	
?>
